summaryrefslogtreecommitdiff
path: root/src/net/protocol.h
diff options
context:
space:
mode:
authorPhilipp Sehmisch <tmw@crushnet.org>2007-03-02 23:29:28 +0000
committerPhilipp Sehmisch <tmw@crushnet.org>2007-03-02 23:29:28 +0000
commit58771baadb7529b0b20ca85566ab2790ca5dcd90 (patch)
tree526b458712f46fc6b9cfdcffc98e0a625f656eb6 /src/net/protocol.h
parent3ce08687bb879054f5fa93f456677246cb51afdd (diff)
downloadmana-client-58771baadb7529b0b20ca85566ab2790ca5dcd90.tar.gz
mana-client-58771baadb7529b0b20ca85566ab2790ca5dcd90.tar.bz2
mana-client-58771baadb7529b0b20ca85566ab2790ca5dcd90.tar.xz
mana-client-58771baadb7529b0b20ca85566ab2790ca5dcd90.zip
Implemented communication of being action changes.
Diffstat (limited to 'src/net/protocol.h')
-rw-r--r--src/net/protocol.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/net/protocol.h b/src/net/protocol.h
index eb27af7d..a5205dba 100644
--- a/src/net/protocol.h
+++ b/src/net/protocol.h
@@ -160,12 +160,14 @@ enum {
PGMSG_EQUIP = 0x0112, // B slot
GPMSG_INVENTORY = 0x0120, // { B slot, W item id [, B amount] }*
GPMSG_INVENTORY_FULL = 0x0121, // { B slot, W item id [, B amount] }*
- GPMSG_BEING_ENTER = 0x0200, // B type, W being id
+ GPMSG_BEING_ENTER = 0x0200, // B type, W being id, B action, W*2 position
// player: S name, B hair style, B hair color, B gender
// monster: W type id
GPMSG_BEING_LEAVE = 0x0201, // W being id
GPMSG_ITEM_APPEAR = 0x0202, // W item id, W*2 position
PGMSG_WALK = 0x0260, // W*2 destination
+ PGMSG_ACTION_CHANGE = 0x0270, // B Action
+ GPMSG_BEING_ACTION_CHANGE = 0x0271, // W being id, B action
GPMSG_BEINGS_MOVE = 0x0280, // { W being id, B flags [, C position] [, W*2 destination] }*
GPMSG_ITEMS = 0x0281, // { W item id, W*2 position }*
PGMSG_ATTACK = 0x0290, // B direction
@@ -175,7 +177,6 @@ enum {
PGMSG_USE_ITEM = 0x0300, // L item id
GPMSG_USE_RESPONSE = 0x0301, // B error
GPMSG_BEINGS_DAMAGE = 0x0310, // { W being id, W amount }*
- GPMSG_BEING_DEAD = 0xDEAD, // W being id
// Chat
CPMSG_ERROR = 0x0401, // B error